// Parametrized test case for the ERCOFTAC diffusor.
// Version 1.0 Original files: Hakan Nilsson, Chalmers University of Technology
//         1.0   2008-01-08 Hakan Nilsson, Chalmers University of Technology
//         1.0.1 2008-01-09 Maryse Page, Hydro-Quebec 
//         1.0.2 2008-01-10 Hakan Nilsson, Chalmers University of Technology 
//         1.0.3 2008-01-11 Maryse Page, Hydro-Quebec.
//                          Script m4 only for blocks BC and CD. 
//                          Inlet BC provided at plane D from Measurements
//                          at station -25.
//                          Outlet at plane B.
//                          Correction for the definition of rOut.
//         1.0.4 2008-01-11 Hakan Nilsson, Chalmers University of Technology 
//                          New parametrization variables
//                          Removed unused vertices and definitions
//         1.0.5 2008-01-14 Hakan Nilsson, Chalmers University of Technology 
//                          Modified DCB -> ABC (A at inlet)
//         1.0.6 2008-01-28 Bounous Omar, Chalmers University of Technology
//                          Modified sin to tan in definition of rOut
//         1.0.7 2008-01-29 Maryse Page and Robert Magnan, Hydro-Quebec.
//                          Added 'use Math::Trig;' to calc

//Run using:
//m4 -P blockMeshDict.m4 > blockMeshDict

//m4 definitions:



/*---------------------------------------------------------------------------*\
| =========                 |                                                 |
| \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
|  \\    /   O peration     | Version:  1.4.1                                 |
|   \\  /    A nd           | Web:      http://www.openfoam.org               |
|    \\/     M anipulation  |                                                 |
\*---------------------------------------------------------------------------*/

FoamFile
{
    version         2.0;
    format          ascii;

    root            "";
    case            "";
    instance        "";
    local           "";

    class           dictionary;
    object          blockMeshDict;
}

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

convertToMeters 1;

vertices
(
//Plane A:
(0.0643 -0.064 -2) // Vertex A0 = 0 
(0.0643 0.0643 -2) // Vertex A1 = 1 
(-0.064 0.0643 -2) // Vertex A2 = 2 
(-0.064 -0.0643 -2) // Vertex A3 = 3 
(0.0919 -0.0919 -2) // Vertex A4 = 4 
(0.09192 0.0919 -2) // Vertex A5 = 5 
(-0.09192 0.0919 -2) // Vertex A6 = 6 
(-0.09192 -0.0919 -2) // Vertex A7 = 7 

//Plane B:
(0.0643 -0.064 0) // Vertex B0 = 8 
(0.0643 0.0643 0) // Vertex B1 = 9 
(-0.064 0.0643 0) // Vertex B2 = 10 
(-0.064 -0.0643 0) // Vertex B3 = 11 
(0.0919 -0.0919 0) // Vertex B4 = 12 
(0.09192 0.0919 0) // Vertex B5 = 13 
(-0.09192 0.0919 0) // Vertex B6 = 14 
(-0.09192 -0.0919 0) // Vertex B7 = 15 

);

// Defining blocks:
blocks
(

 //Blocks between plane A and plane B:
    // block0 - positive x O-grid block
    hex (5 1 0 4 13 9 8 12 ) AB
    (6 10 40)
    simpleGrading (5 1 1)
    // block1 - positive y O-grid block
    hex (6 2 1 5 14 10 9 13 ) AB
  (6 10 40)
    simpleGrading (5 1 1)
    // block2 - negative x O-grid block
    hex (7 3 2 6 15 11 10 14 ) AB
   (6 10 40)
    simpleGrading (5 1 1)
    // block3 - negative y O-grid block
    hex (4 0 3 7 12 8 11 15 ) AB
  (6 10 40)
    simpleGrading (5 1 1)
    // block4 - central O-grid block
    hex (0 1 2 3 8 9 10 11 ) AB
    (10 10 40)
    simpleGrading (1 1 1)

);

edges
(
    //Plane A:
    arc 0 1 (0.0728 0 -2)
    arc 1 2 (0 0.0728 -2)
    arc 2 3 (-0.0728 0 -2)
    arc 3 0 (0 -0.0728 -2)
    arc 4 5 (0.13 0 -2)
    arc 5 6 (0 0.13 -2)
    arc 6 7 (-0.13 0 -2)
    arc 7 4 (0 -0.13 -2)

    //Plane B:
    arc 8 9 (0.0728 0 0)
    arc 9 10 (0 0.0728 0)
    arc 10 11 (-0.0728 0 0)
    arc 11 8 (0 -0.0728 0)
    arc 12 13 (0.13 0 0)
    arc 13 14 (0 0.13 0)
    arc 14 15 (-0.13 0 0)
    arc 15 12 (0 -0.13 0)

);

// Defining patches:
patches
(
    patch inlet
    (

	(1 5 4 0)
       (2 6 5 1)
       (3 7 6 2)
       (0 4 7 3)
       (3 2 1 0)
    )
    patch outlet
    (
	(13 9 8 12)
	(14 10 9 13)
	(15 11 10 14)
	(12 8 11 15)
	(8 9 10 11)

    )

    wall wallDiffuser
    (
       (4 5 13 12)
       (5 6 14 13)
       (6 7 15 14)
       (7 4 12 15)
     )

);

mergePatchPairs 
(
);

// ************************************************************************* //
